@@ -2,34 +2,43 @@ use 5.006;
 use strict;
 use warnings;
 no warnings qw(uninitialized redefine);
-
 package Apache::Wyrd::Request;
-our $VERSION = '0.97';
-
-#set environment variables WYRD_USE_CGI or WYRD_USE_APR
-#to force the use of libapreq or CGI
-my $force_apr = 0;
-my $force_cgi = 0;
-if ($ENV{WYRD_USE_CGI}) {
-	$force_cgi = 1;
-}
-if ($ENV{WYRD_USE_APR}) {
-	$force_apr = 1;
-}
+our $VERSION = '0.98';
 
 my $have_apr = 1;
-my $init_error = '';
-if (!$force_cgi) {
-	eval('use Apache::Request');
-	if ($@) {
-		$init_error = $@;
-		die "$@" if ($force_apr);
+
+if ($ENV{AUTOMATED_TESTING}) {
+
+	#If this is a smoker, the APR method is required.
+	use Apache::Request;
+
+} else {
+
+	#set environment variables WYRD_USE_CGI or WYRD_USE_APR
+	#to force the use of libapreq or CGI
+	my $force_apr = 0;
+	my $force_cgi = 0;
+	if ($ENV{WYRD_USE_CGI}) {
+		$force_cgi = 1;
 	}
-}
-if ($init_error or $force_cgi) {
-	eval('use CGI qw(param)');
-	die "$@" if ($@);
-	$have_apr = 0;
+	if ($ENV{WYRD_USE_APR}) {
+		$force_apr = 1;
+	}
+	
+	my $init_error = '';
+	if (!$force_cgi) {
+		eval('use Apache::Request');
+		if ($@) {
+			$init_error = $@;
+			die "$@" if ($force_apr);
+		}
+	}
+	if ($init_error or $force_cgi) {
+		eval('use CGI qw(param)');
+		die "$@" if ($@);
+		$have_apr = 0;
+	}
+
 }
 
 =pod
