@@ -10,7 +10,9 @@ sub _format_output {
 		file => $file,
 		attributes => [qw(regular map)],
 		maps => [qw(map)],
-		strict => 1
+		strict => 1,
+		bigfile => 0,
+		debug => 1
 	});
 	$index->update_entry($self);
 }
@@ -31,4 +33,10 @@ sub index_map {
 	return $self->{'map'};
 }
 
+sub index_timestamp {
+	my ($self) = @_;
+	return $self->dbl->mtime unless($self->_flags->now);
+	return time;
+}
+
 1;
\ No newline at end of file
